hotspot/src/share/vm/opto/multnode.hpp
changeset 30183 a6588c0a3259
parent 22234 da823d78ad65
child 32084 7743e6943cdf
--- a/hotspot/src/share/vm/opto/multnode.hpp	Sat Mar 14 16:13:48 2015 +0000
+++ b/hotspot/src/share/vm/opto/multnode.hpp	Tue Mar 17 10:06:31 2015 +0100
@@ -89,13 +89,18 @@
   virtual void dump_spec(outputStream *st) const;
 #endif
 
-  // Return true if proj is for "proj->[region->..]call_uct"
-  bool is_uncommon_trap_proj(Deoptimization::DeoptReason reason);
-  // Return true for    "if(test)-> proj -> ...
-  //                          |
-  //                          V
-  //                      other_proj->[region->..]call_uct"
-  bool is_uncommon_trap_if_pattern(Deoptimization::DeoptReason reason);
+  // Return uncommon trap call node if proj is for "proj->[region->..]call_uct"
+  // NULL otherwise
+  CallStaticJavaNode* is_uncommon_trap_proj(Deoptimization::DeoptReason reason);
+  // Return uncommon trap call node for    "if(test)-> proj -> ...
+  //                                                 |
+  //                                                 V
+  //                                             other_proj->[region->..]call_uct"
+  // NULL otherwise
+  CallStaticJavaNode* is_uncommon_trap_if_pattern(Deoptimization::DeoptReason reason);
+
+  // Return other proj node when this is a If proj node
+  ProjNode* other_if_proj() const;
 };
 
 #endif // SHARE_VM_OPTO_MULTNODE_HPP